DynamicIconChangerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DynamicIconChangerPlatform
Implementers

Constructors

DynamicIconChangerPlatform()
Constructs a DynamicIconChangerPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getIcon() → Future<String?>
getPlatformVersion() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIcon(String? iconName, {List<String>? androidActiveAliases, bool relaunch = false}) → Future<void>
supportsAlternateIcons() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ DynamicIconChangerPlatform
The default instance of DynamicIconChangerPlatform to use.
getter/setter pair